==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/HashtableModifiedUpdateDepth.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.query;

namespace com.db4o.test
{
	public class HashtableModifiedUpdateDepth
	{
        Hashtable ht;

        public void configure() 
        {
            Db4o.configure().updateDepth(int.MaxValue);
        }

        public void storeOne() 
        {
            ht = new Hashtable();
            ht["hi"] = "five";
        }

        public void testOne() 
        {
            Tester.ensure(ht["hi"].Equals("five"));
            ht["hi"] = "six";
            Tester.store(this);
            Tester.reOpen();
            Query q = Tester.query();
            q.constrain(this.GetType());
            HashtableModifiedUpdateDepth hmud = 
                (HashtableModifiedUpdateDepth) q.execute().next();
            Tester.ensure(hmud.ht["hi"].Equals("six"));
        }

	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/HashtableModifiedUpdateDepth.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.query;

namespace com.db4o.test
{
	public class HashtableModifiedUpdateDepth
	{
        Hashtable ht;

        public void Configure() 
        {
            Db4o.Configure().UpdateDepth(int.MaxValue);
        }

        public void StoreOne() 
        {
            ht = new Hashtable();
            ht["hi"] = "five";
        }

        public void TestOne() 
        {
            Tester.Ensure(ht["hi"].Equals("five"));
            ht["hi"] = "six";
            Tester.Store(this);
            Tester.ReOpen();
            Query q = Tester.Query();
            q.Constrain(this.GetType());
            HashtableModifiedUpdateDepth hmud = 
                (HashtableModifiedUpdateDepth) q.Execute().Next();
            Tester.Ensure(hmud.ht["hi"].Equals("six"));
        }

	}
}
